@@ -189,9 +189,9 @@ class StickPoint:
             outname = self._base_path + 'data/img/' + new_name + '_stick_point.png'
             
             
-        pv.start_xvfb()
-        # pl.show(screenshot=outname, jupyter_backend='panel')
-        pl.show(screenshot=outname, title=title)
+        # pv.start_xvfb()
+        pl.show(screenshot=outname, jupyter_backend='panel')
+        # pl.show(screenshot=outname, title=title)
 
 
     def plot_stick_point(self, box=0, r=None, outname=0):
